@@ -5,8 +5,6 @@ import (
 	"flag"
 	"os"
 
-	"github.com/thoas/go-funk"
-
 	"github.com/openshift/assisted-installer/src/utils"
 
 	"github.com/openshift/assisted-service/models"
@@ -15,7 +13,6 @@ import (
 type Config struct {
 	Role                 string
 	ClusterID            string
-	InfraEnvID           string
 	HostID               string
 	Device               string
 	URL                  string
@@ -24,6 +21,7 @@ type Config struct {
 	MCOImage             string
 	ControllerImage      string
 	AgentImage           string
+	InstallationTimeout  uint
 	PullSecretToken      string `secret:"true"`
 	SkipCertVerification bool
 	CACertPath           string
@@ -32,9 +30,6 @@ type Config struct {
 	NoProxy              string
 	ServiceIPs           string
 	InstallerArgs        []string
-	HighAvailabilityMode string
-	CheckClusterVersion  bool
-	MustGatherImage      string
 }
 
 var GlobalConfig Config
@@ -48,7 +43,6 @@ func ProcessArgs() {
 	ret := &GlobalConfig
 	flag.StringVar(&ret.Role, "role", string(models.HostRoleMaster), "The node role")
 	flag.StringVar(&ret.ClusterID, "cluster-id", "", "The cluster id")
-	flag.StringVar(&ret.InfraEnvID, "infra-env-id", "", "This host infra env id")
 	flag.StringVar(&ret.HostID, "host-id", "", "This host id")
 	flag.StringVar(&ret.Device, "boot-device", "", "The boot device")
 	flag.StringVar(&ret.URL, "url", "", "The BM inventory URL, including a scheme and optionally a port (overrides the host and port arguments")
@@ -59,15 +53,14 @@ func ProcessArgs() {
 		"Assisted Installer Controller image URL")
 	flag.StringVar(&ret.AgentImage, "agent-image", "quay.io/ocpmetal/assisted-installer-agent:latest",
 		"Assisted Installer Agent image URL that will be used to send logs on successful installation")
+	// Remove installation-timeout once the assisted-service stop sending it.
+	flag.UintVar(&ret.InstallationTimeout, "installation-timeout", 120, "Installation timeout in minutes - OBSOLETE")
 	flag.BoolVar(&ret.SkipCertVerification, "insecure", false, "Do not validate TLS certificate")
 	flag.StringVar(&ret.CACertPath, "cacert", "", "Path to custom CA certificate in PEM format")
 	flag.StringVar(&ret.HTTPProxy, "http-proxy", "", "A proxy URL to use for creating HTTP connections outside the cluster")
 	flag.StringVar(&ret.HTTPSProxy, "https-proxy", "", "A proxy URL to use for creating HTTPS connections outside the cluster")
 	flag.StringVar(&ret.NoProxy, "no-proxy", "", "A comma-separated list of destination domain names, domains, IP addresses, or other network CIDRs to exclude proxying")
 	flag.StringVar(&ret.ServiceIPs, "service-ips", "", "All IPs of assisted service node")
-	flag.StringVar(&ret.HighAvailabilityMode, "high-availability-mode", "Full", "high-availability expectations. default is 'Full', which represents the behavior in a \"normal\" cluster. Use 'None' for single-node deployment")
-	flag.BoolVar(&ret.CheckClusterVersion, "check-cluster-version", false, "Do not monitor CVO")
-	flag.StringVar(&ret.MustGatherImage, "must-gather-image", "", "Custom must-gather image")
 
 	var installerArgs string
 	flag.StringVar(&installerArgs, "installer-args", "", "JSON array of additional coreos-installer arguments")
@@ -88,14 +81,4 @@ func ProcessArgs() {
 			printHelpAndExit()
 		}
 	}
-	if ret.HighAvailabilityMode == models.ClusterHighAvailabilityModeNone {
-		validRoles := []string{string(models.HostRoleMaster), string(models.HostRoleBootstrap)}
-		if !funk.ContainsString(validRoles, ret.Role) {
-			println("high-availability-mode is set to None, but host role is %s. should be one of: %s", ret.Role, validRoles)
-			printHelpAndExit()
-		}
-	}
-	if ret.InfraEnvID == "" {
-		ret.InfraEnvID = ret.ClusterID
-	}
 }
