@@ -30,7 +30,6 @@ type Ops interface {
 	Mkdir(dirName string) error
 	WriteImageToDisk(ignitionPath string, device string, progressReporter inventory_client.InventoryClient, extra []string) error
 	Reboot() error
-	SetBootOrder(device string) error
 	ExtractFromIgnition(ignitionPath string, fileToExtract string) error
 	SystemctlAction(action string, args ...string) error
 	PrepareController() error
@@ -43,11 +42,7 @@ type Ops interface {
 	UploadInstallationLogs(isBootstrap bool) (string, error)
 	ReloadHostFile(filepath string) error
 	CreateOpenshiftSshManifest(filePath, template, sshPubKeyPath string) error
-	GetMustGatherLogs(workDir, kubeconfigPath string, images ...string) (string, error)
-	CreateRandomHostname(hostname string) error
-	GetHostname() (string, error)
-	EvaluateDiskSymlink(string) string
-	CreateManifests(string, []byte) error
+	GetMustGatherLogs(workDir string, kubeconfigPath string) (string, error)
 }
 
 const (
@@ -101,20 +96,17 @@ type ExecCommandError struct {
 	WaitStatus int
 }
 
-func removePullSecret(s []string) []string {
-	return strings.Split(strings.ReplaceAll(strings.Join(s, " "), config.GlobalConfig.PullSecretToken, "<SECRET>"), " ")
-}
-
 func (e *ExecCommandError) Error() string {
 	lastOutput := e.Output
 	if len(e.Output) > 200 {
 		lastOutput = "... " + e.Output[len(e.Output)-200:]
 	}
-	return fmt.Sprintf("failed executing %s %v, Error %s, LastOutput \"%s\"", e.Command, removePullSecret(e.Args), e.ExitErr, lastOutput)
+
+	return fmt.Sprintf("failed executing %s %v, Error %s, LastOutput \"%s\"", e.Command, e.Args, e.ExitErr, lastOutput)
 }
 
 func (e *ExecCommandError) DetailedError() string {
-	return fmt.Sprintf("failed executing %s %v, env vars %v, error %s, waitStatus %d, Output \"%s\"", e.Command, removePullSecret(e.Args), removePullSecret(e.Env), e.ExitErr, e.WaitStatus, e.Output)
+	return fmt.Sprintf("failed executing %s %v, env vars %v, error %s, waitStatus %d, Output \"%s\"", e.Command, e.Args, e.Env, e.ExitErr, e.WaitStatus, e.Output)
 }
 
 // ExecCommand executes command.
@@ -153,13 +145,10 @@ func (o *ops) ExecCommand(liveLogger io.Writer, command string, args ...string)
 				execErr.WaitStatus = status.ExitStatus()
 			}
 		}
-		if liveLogger != nil {
-			//If the caller didn't provide liveLogger the log isn't interesting and might spam
-			o.log.Info(execErr.DetailedError())
-		}
+		o.log.Info(execErr.DetailedError())
 		return output, execErr
 	}
-	o.log.Debug("Command executed:", " command", command, " arguments", removePullSecret(args), "env vars", removePullSecret(cmd.Env), "output", output)
+	o.log.Debug("Command executed:", " command", command, " arguments", args, "env vars", cmd.Env, "output", output)
 	return output, err
 }
 
@@ -181,29 +170,11 @@ func (o *ops) SystemctlAction(action string, args ...string) error {
 func (o *ops) WriteImageToDisk(ignitionPath string, device string, progressReporter inventory_client.InventoryClient, extraArgs []string) error {
 	allArgs := installerArgs(ignitionPath, device, extraArgs)
 	o.log.Infof("Writing image and ignition to disk with arguments: %v", allArgs)
-	_, err := o.ExecPrivilegeCommand(NewCoreosInstallerLogWriter(o.log, progressReporter, config.GlobalConfig.InfraEnvID, config.GlobalConfig.HostID),
+	_, err := o.ExecPrivilegeCommand(NewCoreosInstallerLogWriter(o.log, progressReporter, config.GlobalConfig.HostID),
 		"coreos-installer", allArgs...)
 	return err
 }
 
-func (o *ops) EvaluateDiskSymlink(device string) string {
-	// Overcome https://github.com/coreos/coreos-installer/issues/512 bug.
-	// coreos-installer has a bug where when a disk has busy partitions, it will
-	// print a confusing error message if that disk doesn't have a `/dev/*` style path.
-	// The service may give us paths that don't have the `/dev/*` path format but instead
-	// are symlinks to the actual `/dev/*` path. e.g. `/dev/disk/by-id/wwn-*`.
-	// To fix the bug we simply resolve the symlink and pass the resolved link to coreos-installer.
-	linkTarget, err := filepath.EvalSymlinks(device)
-	if err != nil {
-		o.log.Warnf("Failed to filepath.EvalSymlinks(%s): %s. Continuing with %s anyway.",
-			device, err.Error(), device)
-	} else {
-		o.log.Infof("Resolving installation device %s symlink to %s ", device, linkTarget)
-		device = linkTarget
-	}
-	return device
-}
-
 func installerArgs(ignitionPath string, device string, extra []string) []string {
 	allArgs := []string{"install", "--insecure", "-i", ignitionPath}
 	if extra != nil {
@@ -222,26 +193,8 @@ func (o *ops) Reboot() error {
 	return nil
 }
 
-func (o *ops) SetBootOrder(device string) error {
-	_, err := o.ExecPrivilegeCommand(nil, "test", "-d", "/sys/firmware/efi")
-	if err != nil {
-		o.log.Info("setting the boot order on BIOS systems is not supported. Skipping...")
-		return nil
-	}
-
-	o.log.Info("Setting efibootmgr to boot from disk")
-
-	// efi-system is installed onto partition 2
-	_, err = o.ExecPrivilegeCommand(o.logWriter, "efibootmgr", "-d", device, "-p", "2", "-c", "-L", "Red Hat Enterprise Linux", "-l", "\\EFI\\redhat\\shimx64.efi")
-	if err != nil {
-		o.log.Errorf("Failed to set efibootmgr to boot from disk %s, err: %s", device, err)
-		return err
-	}
-	return nil
-}
-
 func (o *ops) ExtractFromIgnition(ignitionPath string, fileToExtract string) error {
-	o.log.Infof("Getting data from %s", ignitionPath)
+	o.log.Infof("Getting pull secret from %s", ignitionPath)
 	ignitionData, err := ioutil.ReadFile(ignitionPath)
 	if err != nil {
 		o.log.Errorf("Error occurred while trying to read %s : %e", ignitionPath, err)
@@ -313,9 +266,6 @@ func (o *ops) renderControllerCm() error {
 		"ClusterId":            config.GlobalConfig.ClusterID,
 		"SkipCertVerification": strconv.FormatBool(config.GlobalConfig.SkipCertVerification),
 		"CACertPath":           config.GlobalConfig.CACertPath,
-		"HaMode":               config.GlobalConfig.HighAvailabilityMode,
-		"CheckCVO":             config.GlobalConfig.CheckClusterVersion,
-		"MustGatherImage":      config.GlobalConfig.MustGatherImage,
 	}
 
 	return o.renderDeploymentFiles(filepath.Join(controllerDeployFolder, controllerDeployCmTemplate),
@@ -333,9 +283,8 @@ func (o *ops) renderControllerSecret() error {
 
 func (o *ops) renderControllerPod() error {
 	var params = map[string]interface{}{
-		"ControllerImage":  config.GlobalConfig.ControllerImage,
-		"CACertPath":       config.GlobalConfig.CACertPath,
-		"OpenshiftVersion": config.GlobalConfig.OpenshiftVersion,
+		"ControllerImage": config.GlobalConfig.ControllerImage,
+		"CACertPath":      config.GlobalConfig.CACertPath,
 	}
 
 	if config.GlobalConfig.ServiceIPs != "" {
@@ -452,7 +401,7 @@ func (o *ops) GetMCSLogs() (string, error) {
 
 func (o *ops) UploadInstallationLogs(isBootstrap bool) (string, error) {
 	command := "podman"
-	args := []string{"run", "--rm", "--privileged", "--net=host", "--pid=host", "-v", "/run/systemd/journal/socket:/run/systemd/journal/socket",
+	args := []string{"run", "--rm", "--privileged", "--net=host", "-v", "/run/systemd/journal/socket:/run/systemd/journal/socket",
 		"-v", "/var/log:/var/log", config.GlobalConfig.AgentImage, "logs_sender",
 		"-cluster-id", config.GlobalConfig.ClusterID, "-url", config.GlobalConfig.URL,
 		"-host-id", config.GlobalConfig.HostID,
@@ -517,14 +466,10 @@ func (o *ops) CreateOpenshiftSshManifest(filePath, tmpl, sshPubKeyPath string) e
 	return nil
 }
 
-func (o *ops) GetMustGatherLogs(workDir, kubeconfigPath string, images ...string) (string, error) {
+func (o *ops) GetMustGatherLogs(workDir string, kubeconfigPath string) (string, error) {
 	//invoke oc adm must-gather command in the working directory
-	var imageOption string = ""
-	for _, img := range images {
-		imageOption = imageOption + fmt.Sprintf(" --image=%s", img)
-	}
-
-	command := fmt.Sprintf("cd %s && oc --kubeconfig=%s adm must-gather%s", workDir, kubeconfigPath, imageOption)
+	o.log.Infof("collecting must-gather logs into %s", workDir)
+	command := fmt.Sprintf("cd %s && oc --kubeconfig=%s adm must-gather", workDir, kubeconfigPath)
 	output, err := o.ExecCommand(o.logWriter, "bash", "-c", command)
 	if err != nil {
 		return "", err
@@ -556,38 +501,3 @@ func (o *ops) GetMustGatherLogs(workDir, kubeconfigPath string, images ...string
 	}
 	return path.Join(workDir, tarName), nil
 }
-
-func (o *ops) CreateRandomHostname(hostname string) error {
-	command := fmt.Sprintf("echo %s > /etc/hostname", hostname)
-	o.log.Infof("create random hostname with command %s", command)
-	_, err := o.ExecPrivilegeCommand(o.logWriter, "bash", "-c", command)
-	return err
-}
-
-func (o *ops) GetHostname() (string, error) {
-	return os.Hostname()
-}
-
-func (o *ops) CreateManifests(kubeconfig string, content []byte) error {
-	// Create temp file, where we store the content to be create by oc command:
-	file, err := ioutil.TempFile("", "operator-manifest")
-	if err != nil {
-		return err
-	}
-	defer os.Remove(file.Name())
-
-	// Write the content to the temporary file:
-	if err = ioutil.WriteFile(file.Name(), content, 0644); err != nil {
-		return err
-	}
-
-	// Run oc command that creates the custom manifest:
-	command := fmt.Sprintf("oc --kubeconfig=%s apply -f %s", kubeconfig, file.Name())
-	output, err := o.ExecCommand(o.logWriter, "bash", "-c", command)
-	if err != nil {
-		return err
-	}
-	o.log.Infof("Applying custom manifest file %s succeed %s", file.Name(), output)
-
-	return nil
-}
