@@ -38,32 +38,27 @@ import (
 	"github.com/dgrijalva/jwt-go"
 	"github.com/ghodss/yaml"
 
+	sdk "github.com/openshift-online/ocm-sdk-go"
 	"github.com/openshift-online/ocm-sdk-go/errors"
-	"github.com/openshift-online/ocm-sdk-go/logging"
 )
 
 // HandlerBuilder contains the data and logic needed to create a new authentication handler. Don't
 // create objects of this type directly, use the NewHandler function instead.
 type HandlerBuilder struct {
-	logger       logging.Logger
+	logger       sdk.Logger
 	publicPaths  []string
 	keysFiles    []string
 	keysURLs     []string
 	keysCAs      *x509.CertPool
 	keysInsecure bool
 	aclFiles     []string
-	service      string
-	error        string
-	operationID  func(*http.Request) string
-	tolerance    time.Duration
-	cookie       string
 	next         http.Handler
 }
 
 // Handler is an HTTP handler that checks authentication using the JWT tokens from the authorization
 // header.
 type Handler struct {
-	logger        logging.Logger
+	logger        sdk.Logger
 	publicPaths   []*regexp.Regexp
 	tokenParser   *jwt.Parser
 	keysFiles     []string
@@ -72,25 +67,18 @@ type Handler struct {
 	keys          *sync.Map
 	lastKeyReload time.Time
 	aclItems      map[string]*regexp.Regexp
-	service       string
-	error         string
-	operationID   func(*http.Request) string
-	tolerance     time.Duration
-	cookie        string
 	next          http.Handler
 }
 
 // NewHandler creates a builder that can then be configured and used to create authentication
 // handlers.
 func NewHandler() *HandlerBuilder {
-	return &HandlerBuilder{
-		cookie: defaultCookie,
-	}
+	return &HandlerBuilder{}
 }
 
 // Logger sets the logger that the middleware will use to send messages to the log. This is
 // mandatory.
-func (b *HandlerBuilder) Logger(value logging.Logger) *HandlerBuilder {
+func (b *HandlerBuilder) Logger(value sdk.Logger) *HandlerBuilder {
 	b.logger = value
 	return b
 }
@@ -172,106 +160,6 @@ func (b *HandlerBuilder) Next(value http.Handler) *HandlerBuilder {
 	return b
 }
 
-// Service sets the identifier of the service that will be used to generate error codes. For
-// example, if the value is `my_service` then the JSON for error responses will be like this:
-//
-//	{
-//		"kind": "Error",
-//		"id": "401",
-//		"href": "/api/clusters_mgmt/v1/errors/401",
-//		"code": "MY-SERVICE-401",
-//		"reason": "Bearer token is expired"
-//	}
-//
-// When this isn't explicitly provided the value will be extracted from the second segment of the
-// request path. For example, if the request URL is `/api/clusters_mgmt/v1/cluster` the value will
-// be `clusters_mgmt`.
-func (b *HandlerBuilder) Service(value string) *HandlerBuilder {
-	b.service = value
-	return b
-}
-
-// Error sets the error identifier that will be used to generate JSON error responses. For example,
-// if the value is `123` then the JSON for error responses will be like this:
-//
-//	{
-//		"kind": "Error",
-//		"id": "11",
-//		"href": "/api/clusters_mgmt/v1/errors/11",
-//		"code": "CLUSTERS-MGMT-11",
-//		"reason": "Bearer token is expired"
-//	}
-//
-// When this isn't explicitly provided the value will be `401`. Note that changing this doesn't
-// change the HTTP response status, that will always be 401.
-func (b *HandlerBuilder) Error(value string) *HandlerBuilder {
-	b.error = value
-	return b
-}
-
-// OperationID sets a function that will be called each time an error is detected, passing the
-// details of the request that caused the error. The value returned by the function will be included
-// in the `operation_id` field of the JSON error response. For example, if the function returns
-// `123` the generated JSON error response will be like this:
-//
-//	{
-//		"kind": "Error",
-//		"id": "401",
-//		"href": "/api/clusters_mgmt/v1/errors/401",
-//		"code": "CLUSTERS-MGMT-401",
-//		"reason": "Bearer token is expired".
-//		"operation_id": "123"
-//	}
-//
-// For example, if the operation identifier is available in an HTTP header named `X-Operation-ID`
-// then the handler can be configured like this to use it:
-//
-//	handler, err := authentication.NewHandler().
-//		Logger(logger).
-//		KeysURL("https://...").
-//		OperationID(func(r *http.Request) string {
-//			return r.Header.Get("X-Operation-ID")
-//		}).
-//		Next(next).
-//		Build()
-//	if err != nil {
-//		...
-//	}
-//
-// If the function returns an empty string then the `operation_id` field will not be added.
-//
-// By default there is no function configured for this, so no `operation_id` field will be added.
-func (b *HandlerBuilder) OperationID(value func(r *http.Request) string) *HandlerBuilder {
-	b.operationID = value
-	return b
-}
-
-// Tolerance sets the maximum time that a token will be considered valid after it has expired. For
-// example, to accept requests with tokens that have expired up to five minutes ago:
-//
-//	handler, err := authentication.NewHandler().
-//		Logger(logger).
-//		KeysURL("https://...").
-//		Tolerance(5 * time.Minute).
-//		Next(next).
-//		Build()
-//	if err != nil {
-//		...
-//	}
-//
-// The default value is zero tolerance.
-func (b *HandlerBuilder) Tolerance(value time.Duration) *HandlerBuilder {
-	b.tolerance = value
-	return b
-}
-
-// Cookie sets the name of the cookie where the bearer token will be extracted from when the
-// `Authorization` header isn't present. The default is `cs_jwt`.
-func (b *HandlerBuilder) Cookie(value string) *HandlerBuilder {
-	b.cookie = value
-	return b
-}
-
 // Build uses the data stored in the builder to create a new authentication handler.
 func (b *HandlerBuilder) Build() (handler *Handler, err error) {
 	// Check parameters:
@@ -279,10 +167,6 @@ func (b *HandlerBuilder) Build() (handler *Handler, err error) {
 		err = fmt.Errorf("logger is mandatory")
 		return
 	}
-	if b.tolerance < 0 {
-		err = fmt.Errorf("tolerance must be zero or positive")
-		return
-	}
 	if b.next == nil {
 		err = fmt.Errorf("next handler is mandatory")
 		return
@@ -299,7 +183,7 @@ func (b *HandlerBuilder) Build() (handler *Handler, err error) {
 		var info os.FileInfo
 		info, err = os.Stat(file)
 		if err != nil {
-			err = fmt.Errorf("keys file '%s' doesn't exist: %w", file, err)
+			err = fmt.Errorf("keys file '%s' doesn't exist: %v", file, err)
 			return
 		}
 		if !info.Mode().IsRegular() {
@@ -313,12 +197,12 @@ func (b *HandlerBuilder) Build() (handler *Handler, err error) {
 		var parsed *url.URL
 		parsed, err = url.Parse(addr)
 		if err != nil {
-			err = fmt.Errorf("keys URL '%s' isn't a valid URL: %w", addr, err)
+			err = fmt.Errorf("keys URL '%s' isn't a valid URL: %v", addr, err)
 			return
 		}
 		if !strings.EqualFold(parsed.Scheme, "https") {
 			err = fmt.Errorf(
-				"keys URL '%s' doesn't use the HTTPS protocol: %w",
+				"keys URL '%s' doesn't use the HTTPS protocol: %v",
 				addr, err,
 			)
 		}
@@ -375,11 +259,6 @@ func (b *HandlerBuilder) Build() (handler *Handler, err error) {
 		keysClient:  keysClient,
 		keys:        keys,
 		aclItems:    aclItems,
-		service:     b.service,
-		error:       b.error,
-		operationID: b.operationID,
-		tolerance:   b.tolerance,
-		cookie:      b.cookie,
 		next:        b.next,
 	}
 
@@ -431,81 +310,64 @@ func (h *Handler) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 		}
 	}
 
-	// Try to extract the credentials from the `Authorization` header:
-	var bearer string
+	// Extract the bearer token from the authorization header:
 	header := r.Header.Get("Authorization")
-	if header != "" {
-		matches := bearerRE.FindStringSubmatch(header)
-		if len(matches) != 3 {
-			h.sendError(
-				w, r,
-				"Authorization header '%s' is malformed",
-				header,
-			)
-			return
-		}
-		scheme := matches[1]
-		if !strings.EqualFold(scheme, "Bearer") {
+	if header == "" {
+		h.sendError(
+			w, r,
+			"Request doesn't contain the 'Authorization' header",
+		)
+		return
+	}
+	matches := bearerRE.FindStringSubmatch(header)
+	if len(matches) != 3 {
+		h.sendError(
+			w, r,
+			"Authorization header '%s' is malformed",
+			header,
+		)
+		return
+	}
+	typ := matches[1]
+	bearer := matches[2]
+
+	if strings.EqualFold(typ, "AccessToken") {
+		// Set JWT to nil since there is an AccessToken authorization header
+		ctx = ContextWithToken(ctx, nil)
+	} else {
+		if !strings.EqualFold(typ, "Bearer") {
 			h.sendError(
 				w, r,
 				"Authentication type '%s' isn't supported",
-				scheme,
+				typ,
 			)
 			return
 		}
-		bearer = matches[2]
-	}
 
-	// If it wasn't possible to extract the credentials from the `Authorization` header then try
-	// to get them from the cookies:
-	if bearer == "" && h.cookie != "" {
-		for _, cookie := range r.Cookies() {
-			if cookie.Name == h.cookie {
-				bearer = cookie.Value
-			}
+		// Use the JWT library to verify that the token is correctly signed and that the basic
+		// claims are correct:
+		token, claims, ok := h.checkToken(w, r, bearer)
+		if !ok {
+			return
 		}
-	}
 
-	// Report an error if after tying headers and cookies we still don't have credentials:
-	if bearer == "" {
-		if h.cookie != "" {
-			h.sendError(
-				w, r,
-				"Request doesn't contain the 'Authorization' header or "+
-					"the '%s' cookie",
-				h.cookie,
-			)
-		} else {
-			h.sendError(
-				w, r,
-				"Request doesn't contain the 'Authorization' header",
-			)
+		// The library that we use considers tokens valid if the claims that it checks don't exist,
+		// but we want to reject those tokens, so we need to do some additional validations:
+		ok = h.checkClaims(w, r, claims)
+		if !ok {
+			return
 		}
-		return
+
+		// Check if the claims match at least one of the ACL items:
+		ok = h.checkACL(w, r, claims)
+		if !ok {
+			return
+		}
+
+		// Add the token to the context:
+		ctx = ContextWithToken(ctx, token)
 	}
 
-	// Use the JWT library to verify that the token is correctly signed and that the basic
-	// claims are correct:
-	token, claims, ok := h.checkToken(w, r, bearer)
-	if !ok {
-		return
-	}
-
-	// The library that we use considers tokens valid if the claims that it checks don't exist,
-	// but we want to reject those tokens, so we need to do some additional validations:
-	ok = h.checkClaims(w, r, claims)
-	if !ok {
-		return
-	}
-
-	// Check if the claims match at least one of the ACL items:
-	ok = h.checkACL(w, r, claims)
-	if !ok {
-		return
-	}
-
-	// Add the token to the context:
-	ctx = ContextWithToken(ctx, token)
 	r = r.WithContext(ctx)
 
 	// Call the next handler:
@@ -749,75 +611,44 @@ func (h *Handler) checkToken(w http.ResponseWriter, r *http.Request,
 					w, r,
 					"Bearer token is malformed",
 				)
-				ok = false
 			case typed.Errors&jwt.ValidationErrorUnverifiable != 0:
 				h.sendError(
 					w, r,
 					"Bearer token can't be verified",
 				)
-				ok = false
 			case typed.Errors&jwt.ValidationErrorSignatureInvalid != 0:
 				h.sendError(
 					w, r,
 					"Signature of bearer token isn't valid",
 				)
-				ok = false
 			case typed.Errors&jwt.ValidationErrorExpired != 0:
-				// When the token is expired according to the JWT library we may
-				// still want to accept it if we have a configured tolerance:
-				if h.tolerance > 0 {
-					var remaining time.Duration
-					_, remaining, err = tokenRemaining(token, time.Now())
-					if err != nil {
-						h.logger.Error(
-							ctx,
-							"Can't check token duration: %v",
-							err,
-						)
-						remaining = 0
-					}
-					if -remaining <= h.tolerance {
-						ok = true
-					} else {
-						h.sendError(
-							w, r,
-							"Bearer token is expired",
-						)
-						ok = false
-					}
-				} else {
-					h.sendError(
-						w, r,
-						"Bearer token is expired",
-					)
-					ok = false
-				}
+				h.sendError(
+					w, r,
+					"Bearer token is expired",
+				)
 			case typed.Errors&jwt.ValidationErrorIssuedAt != 0:
 				h.sendError(
 					w, r,
 					"Bearer token was issued in the future",
 				)
-				ok = false
 			case typed.Errors&jwt.ValidationErrorNotValidYet != 0:
 				h.sendError(
 					w, r,
 					"Bearer token isn't valid yet",
 				)
-				ok = false
 			default:
 				h.sendError(
 					w, r,
 					"Bearer token isn't valid",
 				)
-				ok = false
 			}
 		default:
 			h.sendError(
 				w, r,
 				"Bearer token is malformed",
 			)
-			ok = false
 		}
+		ok = false
 		return
 	}
 	ok = true
@@ -953,35 +784,23 @@ func (h *Handler) sendError(w http.ResponseWriter, r *http.Request, format strin
 	segments := strings.Split(r.URL.Path, "/")
 	realm := ""
 	builder := errors.NewError()
-	id := h.error
-	if id == "" {
-		id = fmt.Sprintf("%d", http.StatusUnauthorized)
-	}
-	builder.ID(id)
+	builder.ID(fmt.Sprintf("%d", http.StatusUnauthorized))
 	if len(segments) >= 4 {
-		service := h.service
-		if h.service == "" {
-			service = segments[2]
-		}
+		prefix := segments[1]
+		service := segments[2]
 		version := segments[3]
 		builder.HREF(fmt.Sprintf(
-			"/%s/%s/%s/errors/%s",
-			segments[1], segments[2], segments[3], id,
+			"/%s/%s/%s/errors/%d",
+			prefix, service, version, http.StatusUnauthorized,
 		))
 		builder.Code(fmt.Sprintf(
-			"%s-%s",
+			"%s-%d",
 			strings.ToUpper(strings.ReplaceAll(service, "_", "-")),
-			id,
+			http.StatusUnauthorized,
 		))
 		realm = fmt.Sprintf("%s/%s", service, version)
 	}
 	builder.Reason(fmt.Sprintf(format, args...))
-	if h.operationID != nil {
-		operationID := h.operationID(r)
-		if operationID != "" {
-			builder.OperationID(operationID)
-		}
-	}
 	body, err := builder.Build()
 	if err != nil {
 		h.logger.Error(ctx, "Can't build error response: %v", err)
@@ -990,22 +809,8 @@ func (h *Handler) sendError(w http.ResponseWriter, r *http.Request, format strin
 
 	// Send the response:
 	w.Header().Set("WWW-Authenticate", fmt.Sprintf("Bearer realm=\"%s\"", realm))
-	w.Header().Set("Content-Type", "application/json")
-	w.WriteHeader(http.StatusUnauthorized)
-	err = errors.MarshalError(body, w)
-	if err != nil {
-		h.logger.Error(
-			r.Context(),
-			"Can't send response body for request '%s': %v",
-			r.URL.Path,
-			err,
-		)
-	}
+	errors.SendError(w, r, body)
 }
 
 // Regular expression used to extract the bearer token from the authorization header:
 var bearerRE = regexp.MustCompile(`^([a-zA-Z0-9]+)\s+(.*)$`)
-
-// Name of the cookie used to extract the bearer token when the `Authorization` header isn't
-// part of the request
-var defaultCookie = "cs_jwt"
